@@ -335,7 +335,7 @@ class DBConnect:
                 find_data = self.mongo_collection.find(find_dict).limit(
                     limit).skip(offset)
             # 处理返回数据
-            records_filtered = len(find_data)
+            records_filtered = len(handle_db_to_list(find_data))
             # 判断数据是否为空
             if records_filtered:
                 # 处理返回数据
