@@ -31,6 +31,8 @@ class Parameter():
         }
 
     def verification(self, checking: dict, verify: dict, optional: dict = {}, null_value: bool = False, allow_extra: bool = False) -> dict:
+        if type(checking) != dict:
+            handle_abnormal(message='请求格式不规范', status=400)
         for opt_k, opt_v in optional.items():
             # 没有选填参数时，填充预设的默认值
             if not checking.__contains__(opt_k):
